
# Type: inherited


true means that the *value* of a slot is inherited by subclasses

URI: [meta:inherited](https://w3id.org/biolink/biolinkml/meta/inherited)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Inherited applies to slot values.  Parent *slots* are always inherited by subclasses |

